@@ -1,6 +1,10 @@
-# ------------------------------------------------------------------------------
+# --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
-# ------------------------------------------------------------------------------
+#
+# This file is part of the tsfpga project.
+# https://tsfpga.com
+# https://gitlab.com/tsfpga/tsfpga
+# --------------------------------------------------------------------------------------------------
 
 
 class HdlFile:
@@ -16,7 +20,7 @@ class HdlFile:
 
     def __init__(self, path):
         """
-        Args:
+        Arguments:
             path (`pathlib.Path`): Path to a HDL source code  file.
         """
         self.path = path
@@ -43,4 +47,4 @@ class HdlFile:
         return self.path.name.endswith(self.verilog_header_file_ending)
 
     def __str__(self):
-        return str(self.path)
+        return f"{self.__class__.__name__}('{self.path}')"
