@@ -1,6 +1,10 @@
-# ------------------------------------------------------------------------------
+# --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
-# ------------------------------------------------------------------------------
+#
+# This file is part of the tsfpga project.
+# https://tsfpga.com
+# https://gitlab.com/tsfpga/tsfpga
+# --------------------------------------------------------------------------------------------------
 
 from .simlib_commercial import VivadoSimlibCommercial
 from .simlib_ghdl import VivadoSimlibGhdl
@@ -18,7 +22,7 @@ class VivadoSimlib:
         Get a Vivado simlib API suitable for your current simulator. Uses VUnit mechanism
         for detecting the simulator currently in use.
 
-        Args:
+        Arguments:
             output_path (`pathlib.Path`): The compiled simlib will be placed here.
             vunit_proj: The VUnit project that is used to run simulation.
             vivado_path (`pathlib.Path`): Path to Vivado executable. If left out, the default
